﻿namespace NesterovskyBros.DataStream
{
  using System;
  using System.Collections.Generic;
  using System.Linq;
  using System.Text;
  using System.Runtime.Serialization;

  /// <summary>
  /// Data sourcre class (as if entity objects).
  /// Idea is taken from KendoUI test data sources.
  /// </summary>
  public static class Data
  {
    private static readonly string[] firstNames = 
    {
      "Nancy", "Andrew", "Janet", "Margaret", "Steven", 
      "Michael", "Robert", "Laura", "Anne", "Alex", 
      "Joe", "Sandra", "Ray", "Richard"
    };

    private static readonly string[] lastNames = 
    {
      "Davolio", "Fuller", "Leverling", "Peacock", "Buchanan", 
      "Suyama", "King", "Callahan", "Dodsworth", "White",
      "Black", "Tucker", "Longley", "Lloyd", "McCartney", 
      "Jonson", "Freeman", "Smith", "Goldman", "Nevill",
      "Lawrence", "Ruggier", "Bullock", "Charles"
    };

    private static readonly string[] cities = 
    {
      "Seattle", "Tacoma", "Kirkland", "Redmond", "London", 
      "Philadelphia", "New York", "Seattle", "London", "Boston",
      "Chicago"
    };

    private static readonly string[] titles = 
    {
      "Accountant", "Software Developer", "Sales Representative", 
      "Technical Support", "Sales Manager", "Software Engineer",
      "Vice President, Sales", "Web Designer", 
      "Chief Techical Officer", "Chief Execute Officer",
      "Financial Analyst", "Inside Sales Coordinator"
    };

    private static readonly DateTime[] birthDates = 
    {
      new DateTime(1968, 12, 8), 
      new DateTime(1952, 2, 19), 
      new DateTime(1963, 8, 30), 
      new DateTime(1972, 9, 19), 
      new DateTime(1955, 3, 4), 
      new DateTime(1963, 7, 2), 
      new DateTime(1960, 5, 29), 
      new DateTime(1958, 1, 9), 
      new DateTime(1966, 1, 27), 
      new DateTime(1966, 3, 27),
      new DateTime(1973, 6, 12), 
      new DateTime(1975, 2, 1),
      new DateTime(1979, 10, 5), 
      new DateTime(1982, 9, 8),
      new DateTime(1983, 7, 12), 
      new DateTime(1991, 3, 19)
    };

    // GetSex sounds grossly...
    private static string Check(string name)
    {
      switch (name)
      {
        case "Nancy":
        case "Janet":
        case "Margaret":
        case "Laura":
        case "Anne":
        case "Sandra":
        {
          return "F";
        }
        default:
        {
          return "M";
        }
      }
    }


    [DataContract(Name = "person", Namespace = "http://www.nesterovsky-bros.com")]
    public class Person
    {
      [DataMember]
      public int Id { get; set; }
      [DataMember]
      public string FirstName { get; set; }
      [DataMember]
      public string LastName { get; set; }
      [DataMember]
      public string City { get; set; }
      [DataMember]
      public string Title { get; set; }
      [DataMember]
      public DateTime BirthDate { get; set; }
      [DataMember]
      public int Age { get; set; }
      [DataMember]
      public string Sex { get; set; }
    }

    public static IEnumerable<Person> CreateRandomData(
      int count,
      int seed,
      int skip,
      int take)
    {
      var now = DateTime.Today;
      var random = new Random(seed);

      return Enumerable.Range(0, count).
        Select(
          i =>
          {
            var birthDate = birthDates[random.Next(birthDates.Length)];
            var name = firstNames[random.Next(firstNames.Length)];

            return new Person
            {
              Id = i + 1,
              FirstName = name,
              LastName = lastNames[random.Next(lastNames.Length)],
              City = cities[random.Next(cities.Length)],
              Title = titles[random.Next(titles.Length)],
              BirthDate = birthDates[random.Next(birthDates.Length)],
              Age = now.Year - birthDate.Year,
              Sex = Check(name)
            };
          }).
        Skip(skip).
        Take(take);
    }
  }
}
