﻿namespace NesterovskyBros.DataStream
{
  using System;
  using System.Collections.Generic;
  using System.Web;
  using System.IO;

  /// <summary>
  /// A text reader that produces content from a string enumerator.
  /// </summary>
  public class EnumeratorReader: TextReader
  {
    /// <summary>
    /// Creates an EnumeratorReader instance.
    /// </summary>
    /// <param name="source">A text source.</param>
    public EnumeratorReader(IEnumerator<string> source)
    {
      this.source = source;
    }

    /// <summary>
    /// Reads the next character from the input stream and advances the character
    /// position by one character.
    /// </summary>
    /// <returns>
    /// The next character from the input stream, or -1 if no more characters are
    /// available. The default implementation returns -1.
    /// </returns>
    public override int Read()
    {
      while(true)
      {
        if (current != null)
        {
          int c = current[offset++];

          if (offset >= current.Length)
          {
            current = null;
            offset = 0;
          }

          return c;
        }

        if (source == null)
        {
          return -1;
        }

        if (!source.MoveNext())
        {
          source = null;

          return -1;
        }

        current = source.Current;

        if (string.IsNullOrEmpty(current))
        {
          current = null;
        }
      }
    }

    /// <summary>
    /// Source enumerator.
    /// </summary>
    private IEnumerator<string> source;

    /// <summary>
    /// Current item.
    /// </summary>
    private string current;

    /// <summary>
    /// Offset in the current item.
    /// </summary>
    private int offset;
  }
}