<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:nb="http://www.nesterovsky-bros.com"
  xmlns:arg="urn:nesterovsky-bros:args"
  xmlns:fn="urn:nesterovsky-bros:fn"
  xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:o="urn:schemas-microsoft-com:office:office"
  xmlns:x="urn:schemas-microsoft-com:office:excel"
  xmlns:xdr="http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing"
  xmlns:c="http://schemas.openxmlformats.org/drawingml/2006/chart" 
  xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" 
  xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
  exclude-result-prefixes="msxsl fn arg">

  <xsl:param name="arg:sortBy" select="'City'"/>
  
  <xsl:output method="xml" encoding="utf-8" omit-xml-declaration="no" standalone="yes"/>

  <xsl:key name="group-by-city" match="nb:City" use="text()" />
  <xsl:key name="group-by-title" match="nb:Title" use="text()" />
  <xsl:key name="group-by-name" match="nb:LastName" use="text()" />
  <xsl:key name="group-by-age" match="nb:Age" use="text()" />

  <xsl:template match="/">
    <xsl:variable name="people">
      <xsl:copy-of select="fn:GetData('data')"/>
    </xsl:variable>

    <!-- Collect groups. -->
    <xsl:variable name="groups">
      <xsl:choose>
        <xsl:when test="$arg:sortBy = 'City'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:City[generate-id(.)=generate-id(key('group-by-city', text())[1])]"/>
        </xsl:when>
        <xsl:when test="$arg:sortBy = 'Title'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:Title[generate-id(.)=generate-id(key('group-by-title', text())[1])]"/>
        </xsl:when>
        <xsl:when test="$arg:sortBy = 'Age'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:Age[generate-id(.)=generate-id(key('group-by-age', text())[1])]"/>
        </xsl:when>
        <xsl:when test="$arg:sortBy = 'Name'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:LastName[generate-id(.)=generate-id(key('group-by-name', text())[1])]"/>
        </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="counter" select="count(msxsl:node-set($groups)/nb:group) + 1"/>

    <c:chartSpace>
      <c:lang val="he-IL"/>
      <c:chart>
        <c:title>
          <c:layout/>
        </c:title>
        <c:view3D>
          <c:rotX val="50"/>
          <c:depthPercent val="100"/>
          <c:rAngAx val="1"/>
        </c:view3D>
        <c:plotArea>
          <c:layout/>
          <c:pie3DChart>
            <c:varyColors val="1"/>
            <c:ser>
              <c:idx val="0"/>
              <c:order val="0"/>
              <c:tx>
                <c:v>Dispersion by "<xsl:value-of select="$arg:sortBy"/>"</c:v>
              </c:tx>
              <c:dLbls>
                <c:showVal val="1"/>
                <c:showLeaderLines val="1"/>
              </c:dLbls>
              <c:cat>
                <c:strRef>
                  <c:f>chart!$B$2:$B$<xsl:value-of select="$counter"/></c:f>
                  <c:strCache/>
                </c:strRef>
              </c:cat>
              <c:val>
                <c:numRef>
                  <c:f>chart!$A$2:$A$<xsl:value-of select="$counter"/></c:f>
                  <c:numCache/>
                </c:numRef>
              </c:val>
            </c:ser>
          </c:pie3DChart>
        </c:plotArea>
        <c:legend>
          <c:legendPos val="l"/>
          <c:layout/>
          <c:txPr>
            <a:bodyPr/>
            <a:lstStyle/>
            <a:p>
              <a:pPr rtl="0">
                <a:defRPr/>
              </a:pPr>
              <a:endParaRPr lang="he-IL"/>
            </a:p>
          </c:txPr>
        </c:legend>
        <c:plotVisOnly val="1"/>
      </c:chart>
      <c:printSettings>
        <c:headerFooter/>
        <c:pageMargins b="0.75" l="0.7" r="0.7" t="0.75" header="0.3" footer="0.3"/>
        <c:pageSetup/>
      </c:printSettings>
    </c:chartSpace>    
  </xsl:template>

  <xsl:template match="nb:City">
    <nb:group name="{text()}"/>
  </xsl:template>

  <xsl:template match="nb:Title">
    <nb:group name="{text()}"/>
  </xsl:template>

  <xsl:template match="nb:Age">
    <nb:group name="{text()}"/>
  </xsl:template>

  <xsl:template match="nb:LastName">
    <nb:group name="{text()}"/>
  </xsl:template>
</xsl:stylesheet>
    
