<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:nb="http://www.nesterovsky-bros.com"
  xmlns:arg="urn:nesterovsky-bros:args"
  xmlns:fn="urn:nesterovsky-bros:fn"
  xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:o="urn:schemas-microsoft-com:office:office"
  xmlns:x="urn:schemas-microsoft-com:office:excel"
  xmlns:xdr="http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing"
  xmlns="http://schemas.openxmlformats.org/drawingml/2006/main"
  xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
  exclude-result-prefixes="msxsl fn arg">

  <xsl:param name="arg:sortBy" select="'City'"/>

  <xsl:output method="xml" encoding="utf-8" omit-xml-declaration="no" standalone="yes"/>

  <xsl:template match="/">
    <xsl:variable name="people">
      <xsl:copy-of select="fn:GetData('data')"/>
    </xsl:variable>

    <xsl:variable name="counter"
      select="count(msxsl:node-set($people)/nb:people/nb:person)"/>

    <worksheet>
      <dimension ref="A1:E{1 + $counter}"/>
      <sheetViews>
        <sheetView showGridLines="0" rightToLeft="1" tabSelected="1" workbookViewId="0">
          <selection activeCell="A1" sqref="A1"/>
        </sheetView>
      </sheetViews>
      <sheetFormatPr defaultColWidth="10" defaultRowHeight="18" customHeight="1"/>
      <cols>
        <col min="1" max="1" width="4" bestFit="1" customWidth="1"/>
        <col min="2" max="2" width="19.1" bestFit="1" customWidth="1"/>
        <col min="3" max="3" width="9.7" bestFit="1" customWidth="1"/>
        <col min="4" max="4" width="9" bestFit="1" customWidth="1"/>
        <col min="5" max="5" width="9.2" bestFit="1" customWidth="1"/>
      </cols>
      <sheetData>
        <row r="1" spans="1:5">
          <c r="A1" t="inlineStr" s="1">
            <is>
              <t>Age</t>
            </is>
          </c>
          <c r="B1" t="inlineStr" s="1">
            <is>
              <t>Title</t>
            </is>
          </c>
          <c r="C1" t="inlineStr" s="1">
            <is>
              <t>City</t>
            </is>
          </c>
          <c r="D1" t="inlineStr" s="1">
            <is>
              <t>Last Name</t>
            </is>
          </c>
          <c r="E1" t="inlineStr" s="1">
            <is>
              <t>First Name</t>
            </is>
          </c>
        </row>
        <xsl:choose>
          <xsl:when test="$arg:sortBy = 'City'">
            <xsl:for-each select="msxsl:node-set($people)/nb:people/nb:person">
              <xsl:sort select="nb:City"/>
              <xsl:variable name="index" select="position() + 1"/>
              <xsl:variable name="node" select="."/>
              <xsl:call-template name="generate-row">
                <xsl:with-param name="index" select="$index"/>
                <xsl:with-param name="node" select="$node"/>
              </xsl:call-template>
            </xsl:for-each>
          </xsl:when>
          <xsl:when test="$arg:sortBy = 'Title'">
            <xsl:for-each select="msxsl:node-set($people)/nb:people/nb:person">
              <xsl:sort select="nb:Title"/>
              <xsl:variable name="index" select="position() + 1"/>
              <xsl:variable name="node" select="."/>
              <xsl:call-template name="generate-row">
                <xsl:with-param name="index" select="$index"/>
                <xsl:with-param name="node" select="$node"/>
              </xsl:call-template>
            </xsl:for-each>
          </xsl:when>
          <xsl:when test="$arg:sortBy = 'Age'">
            <xsl:for-each select="msxsl:node-set($people)/nb:people/nb:person">
              <xsl:sort select="nb:Age"/>
              <xsl:variable name="index" select="position() + 1"/>
              <xsl:variable name="node" select="."/>
              <xsl:call-template name="generate-row">
                <xsl:with-param name="index" select="$index"/>
                <xsl:with-param name="node" select="$node"/>
              </xsl:call-template>
            </xsl:for-each>
          </xsl:when>
          <xsl:otherwise>
            <xsl:for-each select="msxsl:node-set($people)/nb:people/nb:person">
              <xsl:sort select="nb:LastName"/>
              <xsl:sort select="nb:FirstName"/>
              <xsl:variable name="index" select="position() + 1"/>
              <xsl:variable name="node" select="."/>
              <xsl:call-template name="generate-row">
                <xsl:with-param name="index" select="$index"/>
                <xsl:with-param name="node" select="$node"/>
              </xsl:call-template>
            </xsl:for-each>
          </xsl:otherwise>
        </xsl:choose>
      </sheetData>
      <pageMargins left="0.75" right="0.75" top="1" bottom="1" header="0.5" footer="0.5"/>
      <pageSetup paperSize="9" orientation="portrait" r:id="rId1"/>
    </worksheet>
  </xsl:template>

  <xsl:template name="generate-row">
    <xsl:param name="index" select="0"/>
    <xsl:param name="node"></xsl:param>
    <row r="{$index}" spans="1:5" ht="18" customHeight="1">
      <c r="A{$index}" s="{$index mod 2 + 3}">
        <v>
          <xsl:value-of select="$node/nb:Age"/>
        </v>
      </c>
      <c r="B{$index}" t="inlineStr" s="{$index mod 2 + 3}">
        <is>
          <t>
            <xsl:value-of select="$node/nb:Title"/>
          </t>
        </is>
      </c>
      <c r="C{$index}" t="inlineStr" s="{$index mod 2 + 3}">
        <is>
          <t>
            <xsl:value-of select="$node/nb:City"/>
          </t>
        </is>
      </c>
      <c r="D{$index}" t="inlineStr" s="{$index mod 2 + 3}">
        <is>
          <t>
            <xsl:value-of select="$node/nb:LastName"/>
          </t>
        </is>
      </c>
      <c r="E{$index}" t="inlineStr" s="{$index mod 2 + 3}">
        <is>
          <t>
            <xsl:value-of select="$node/nb:FirstName"/>
          </t>
        </is>
      </c>
    </row>
  </xsl:template>
  </xsl:stylesheet>