<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:nb="http://www.nesterovsky-bros.com"
  xmlns:arg="urn:nesterovsky-bros:args"
  xmlns:fn="urn:nesterovsky-bros:fn"
  xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:o="urn:schemas-microsoft-com:office:office"
  xmlns:x="urn:schemas-microsoft-com:office:excel"
  xmlns:xdr="http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing"
  xmlns="http://schemas.openxmlformats.org/drawingml/2006/main"
  xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
  exclude-result-prefixes="msxsl fn arg">

  <xsl:param name="arg:sortBy" select="'City'"/>

  <xsl:output method="xml" encoding="utf-8" omit-xml-declaration="no" standalone="yes"/>

  <xsl:key name="group-by-city" match="nb:City" use="text()" />
  <xsl:key name="group-by-title" match="nb:Title" use="text()" />
  <xsl:key name="group-by-name" match="nb:LastName" use="text()" />
  <xsl:key name="group-by-age" match="nb:Age" use="text()" />

  <xsl:template match="/">
    <xsl:variable name="people">
      <xsl:copy-of select="fn:GetData('data')"/>
    </xsl:variable>

    <!-- Collect groups. -->
    <xsl:variable name="groups">
      <xsl:choose>
        <xsl:when test="$arg:sortBy = 'City'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:City[generate-id(.)=generate-id(key('group-by-city', text())[1])]"/>
        </xsl:when>
        <xsl:when test="$arg:sortBy = 'Title'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:Title[generate-id(.)=generate-id(key('group-by-title', text())[1])]"/>
        </xsl:when>
        <xsl:when test="$arg:sortBy = 'Age'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:Age[generate-id(.)=generate-id(key('group-by-age', text())[1])]"/>
        </xsl:when>
        <xsl:when test="$arg:sortBy = 'Name'">
          <xsl:apply-templates select="
            msxsl:node-set($people)/nb:people/nb:person/
              nb:LastName[generate-id(.)=generate-id(key('group-by-name', text())[1])]"/>
        </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="counter" select="count(msxsl:node-set($groups)/nb:group)"/>

    <worksheet>
      <dimension ref="A1:B{1 + $counter}"/>
      <sheetViews>
        <sheetView showGridLines="0" rightToLeft="1" tabSelected="1" workbookViewId="0">
          <selection activeCell="A1" sqref="A1"/>
        </sheetView>
      </sheetViews>
      <sheetFormatPr defaultColWidth="10" defaultRowHeight="18" customHeight="1"/>
      <cols>
        <col min="2" max="2" width="20" bestFit="1" customWidth="1"/>
      </cols>
      <sheetData>
        <row r="1" spans="1:2">
          <c r="A1" t="inlineStr" s="8">
            <is>
              <t>Count</t>
            </is>
          </c>
          <c r="B1" t="inlineStr" s="5">
            <is>
              <t><xsl:value-of select="$arg:sortBy"/></t>
            </is>
          </c>
        </row>
        <xsl:for-each select="msxsl:node-set($groups)/nb:group">
          <xsl:sort select="@count" order="descending"/>
          <xsl:sort select="@name" order="ascending"/>
          <xsl:variable name="index" select="position() + 1"/>
          <row r="{$index}" spans="1:2" ht="18" customHeight="1">
            <c r="A{$index}" s="9">
              <v>
                <xsl:value-of select="@count"/>
              </v>
            </c>
            <c r="B{$index}" t="inlineStr" s="6">
              <is>
                <t>
                  <xsl:value-of select="@name"/>
                </t>
              </is>
            </c>
          </row>
        </xsl:for-each>
      </sheetData>
      <pageMargins left="0.7" right="0.7" top="0.75" bottom="0.75" header="0.3" footer="0.3"/>
      <drawing r:id="rId1"/>
    </worksheet>
  </xsl:template>

  <xsl:template match="nb:City">
    <nb:group name="{text()}" count="{count(key('group-by-city', text()))}"/>
  </xsl:template>

  <xsl:template match="nb:Title">
    <nb:group name="{text()}" count="{count(key('group-by-title', text()))}"/>
  </xsl:template>

  <xsl:template match="nb:Age">
    <nb:group name="{text()}" count="{count(key('group-by-age', text()))}"/>
  </xsl:template>

  <xsl:template match="nb:LastName">
    <nb:group name="{text()}" count="{count(key('group-by-name', text()))}"/>
  </xsl:template>
</xsl:stylesheet>
